@@ -15,7 +15,9 @@ def get_db_header(headers=None, api_key=None):
 
     # Retrieve the key from environment or config
     key = api_key or get_env_value('SOLCATCHER_DB_API_KEY')
+    print("DEBUG: api_key ->",str(api_key))
 
+    print("DEBUG: SOLCATCHER_DB_API_KEY ->", str(get_env_value('SOLCATCHER_DB_API_KEY')))
     # If key is not None, add the header; otherwise skip it
     if key:
         headers["X-API-KEY"] = str(key) if key else ""
